@@ -44,15 +44,13 @@ from logzero import logger as log
 
 from . import binning, markdown_table, pid_data, utils
 
-uproot.open.defaults[
-    "xrootd_handler"
-] = uproot.source.xrootd.XRootDSource  # type: ignore
-
 try:
     from .version import version  # type: ignore
 except ImportError:
     version = "N/A"
 
+uproot.open.defaults["xrootd_handler"] = uproot.MultithreadedXRootDSource
+
 
 class ListValidAction(argparse.Action):
     """Class that overrides required parameters and prints valid configs."""
@@ -157,9 +155,9 @@ def decode_arguments(args):
     )
     parser.add_argument(
         "-l",
-        "--list-valid",
+        "--list",
         action=ListValidAction,
-        help="list all valid [configs, aliases]",
+        help="list all [configs, aliases]",
     )
     parser.add_argument(
         "-d",
