@@ -38,8 +38,8 @@ def test_calib_root_to_dataframe():
 def test_get_tree_paths():
     assert pid_data.get_tree_paths("Pi", "26") == ["DecayTree"]
     assert pid_data.get_tree_paths("Pi", "Turbo15") == [
-        "DSt_PiPTuple/DecayTree",
         "DSt_PiMTuple/DecayTree",
+        "DSt_PiPTuple/DecayTree",
     ]
     assert pid_data.get_tree_paths("Mu", "Turbo15-MagUp-Mu") == [
         "Jpsi_MuPTuple/DecayTree",
@@ -48,39 +48,38 @@ def test_get_tree_paths():
 
 
 def test_get_relevant_branch_names():
-    assert pid_data.get_relevant_branch_names("probe", ["DLLK < 4"], ["P"]) == {
+    assert pid_data.get_relevant_branch_names(["DLLK < 4"], ["P"]) == {
         "sWeight": "probe_sWeight",
         "P": "probe_P",
         "DLLK": "probe_PIDK",
     }
 
-    assert pid_data.get_relevant_branch_names("probe", ["DLLp > 4"], ["P", "ETA"]) == {
+    assert pid_data.get_relevant_branch_names(["DLLp > 4"], ["P", "ETA"]) == {
         "sWeight": "probe_sWeight",
         "P": "probe_P",
         "ETA": "probe_ETA",
         "DLLp": "probe_PIDp",
     }
 
-    assert pid_data.get_relevant_branch_names("probe", ["DLLp == 4"], ["P", "ETA"]) == {
+    assert pid_data.get_relevant_branch_names(["DLLp == 4"], ["P", "ETA"]) == {
         "sWeight": "probe_sWeight",
         "P": "probe_P",
         "ETA": "probe_ETA",
         "DLLp": "probe_PIDp",
     }
 
-    assert pid_data.get_relevant_branch_names("probe", ["DLLp != 4"], ["P", "ETA"]) == {
+    assert pid_data.get_relevant_branch_names(["DLLp != 4"], ["P", "ETA"]) == {
         "sWeight": "probe_sWeight",
         "P": "probe_P",
         "ETA": "probe_ETA",
         "DLLp": "probe_PIDp",
     }
 
-    assert pid_data.get_relevant_branch_names(
-        "notprobe", ["DLLp != 4"], ["P", "ETA"]
-    ) == {"P": "notprobe_P", "ETA": "notprobe_ETA", "DLLp": "notprobe_PIDp"}
-
-    with pytest.raises(ValueError):
-        pid_data.get_relevant_branch_names("probe", ["DLLp = 4"], ["P", "ETA"])
+    assert pid_data.get_relevant_branch_names(["test_DLL != 4"], ["special_var"]) == {
+        "sWeight": "probe_sWeight",
+        "test_DLL": "test_DLL",
+        "special_var": "special_var",
+    }
 
 
 def test_dataframe_from_local_file():
@@ -149,48 +148,48 @@ def test_get_calib_hists():
         )
 
 
-def test_get_file_list():
+def test_get_calibration_sample():
     assert (
         len(
-            pid_data.get_file_list(
+            pid_data.get_calibration_sample(
                 "Turbo18", "up", "Pi", str(Path(THIS_DIR, "../data/samples.json"))
-            )
+            )["files"]
         )
         == 428
     )
     assert (
         len(
-            pid_data.get_file_list(
+            pid_data.get_calibration_sample(
                 "Turbo18",
                 "up",
                 "Pi",
                 str(Path(THIS_DIR, "../data/samples.json")),
                 3,
-            )
+            )["files"]
         )
         == 3
     )
     assert (
         len(
-            pid_data.get_file_list(
+            pid_data.get_calibration_sample(
                 "Electron18",
                 "down",
-                "e",
+                "e_B_Jpsi",
                 str(Path(THIS_DIR, "../data/samples.json")),
-            )
+            )["files"]
         )
         == 1
     )
     assert (
         len(
-            pid_data.get_file_list(
+            pid_data.get_calibration_sample(
                 "20", "down", "K", str(Path(THIS_DIR, "../data/samples.json"))
-            )
+            )["files"]
         )
         == 72
     )
 
     with pytest.raises(KeyError):
-        pid_data.get_file_list(
+        pid_data.get_calibration_sample(
             "Turbo34", "up", "Pi", str(Path(THIS_DIR, "../data/samples.json"))
         )
